# Vela Security

If you believe you have identified a security related issue or vulnerability,
then we encourage you to responsibly disclose it to us as soon as possible.

## Reporting Security Issues and Vulnerabilities

Please send an email to <MLG-Security@arm.com> with the subject `Vela Security`.
In the body of the email include as much information as possible about the issue
or vulnerability and any additional contact details.
